#[repr(u8)]pub enum Status {
Updateavailable = 0,
Busy = 1,
Notavailable = 2,
Downloadprotocolnotsupported = 3,
}Variants
Updateavailable = 0
Indicates that the OTA Provider has an update available.
Busy = 1
Indicates OTA Provider may have an update, but it is not ready yet.
Notavailable = 2
Indicates that there is definitely no update currently available from the OTA Provider.
Downloadprotocolnotsupported = 3
Indicates that the requested download protocol is not supported by the OTA Provider.
Implementations